@@ -34,6 +34,7 @@ struct _GgvControlPrivate {
 	GtkWidget *root;
 
 	GtkObject *zoom_adj;
+	BonoboControl *zoom_control;
 
 	BonoboUIComponent *uic, *popup_uic;
 };
@@ -76,9 +77,14 @@ ggv_control_destroy (BonoboObject *object)
 
 	control = GGV_CONTROL (object);
 
-	if (control->priv->root)
-		gtk_widget_unref (control->priv->root);
-	control->priv->root = NULL;
+	if (control->priv->zoom_control) {
+		bonobo_object_unref(BONOBO_OBJECT(control->priv->zoom_control));
+		control->priv->zoom_control = NULL;
+	}
+	if(control->priv->uic) {
+		bonobo_object_unref(BONOBO_OBJECT(control->priv->uic));
+		control->priv->uic = NULL;
+	}
 
 	if(BONOBO_OBJECT_CLASS (ggv_control_parent_class)->destroy)
 		BONOBO_OBJECT_CLASS (ggv_control_parent_class)->destroy (object);
@@ -491,6 +497,16 @@ _set_zoom_items_sensitivity(GgvControl *control, BonoboUIComponent *uic, gboolea
 								 "sensitive", prop_val, NULL);
 	bonobo_ui_component_set_prop(uic, "/commands/ZoomToFitWidth",
 								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_set_prop(uic, "/commands/Zoom0104",
+								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_set_prop(uic, "/commands/Zoom0102",
+								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_set_prop(uic, "/commands/Zoom0101",
+								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_set_prop(uic, "/commands/Zoom0201",
+								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_set_prop(uic, "/commands/Zoom0401",
+								 "sensitive", prop_val, NULL);
 }
 
 static void
@@ -562,7 +578,7 @@ ggv_control_create_ui (GgvControl *control)
 	ggv_postscript_view_set_popup_ui_component(control->priv->ps_view,
 											   control->priv->popup_uic);
 
-	if(!control->priv->has_zoomable_frame || TRUE /* lets set this to nautilus as well */) {
+	if(!control->priv->has_zoomable_frame) {
 		BonoboControl *zoom_control;
 		GtkWidget *zoom_spin, *zoom_image, *perc_label, *hbox;
 		GtkObject *zoom_adj;
@@ -582,10 +598,12 @@ ggv_control_create_ui (GgvControl *control)
 		perc_label = gtk_label_new("%");
 		gtk_widget_show(perc_label);
 		gtk_box_pack_start(GTK_BOX(hbox), perc_label, FALSE, TRUE, 0);
+
 		zoom_control = bonobo_control_new(hbox);
 		bonobo_ui_component_object_set(control->priv->uic, "/Sidebar/Zoom Control Placeholder/ZoomControl",
 									   BONOBO_OBJREF(zoom_control), NULL);
-#if 0
+		control->priv->zoom_control = zoom_control;
+#if 1
 		bonobo_object_unref(BONOBO_OBJECT(zoom_control));
 #endif
 		control->priv->zoom_adj = zoom_adj;
@@ -718,7 +736,6 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 
 	control->priv->root = gtk_scrolled_window_new(ggv_postscript_view_get_hadj(ps_view),
 												  ggv_postscript_view_get_vadj(ps_view));
-	
 	gtk_widget_show(control->priv->root);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(control->priv->root),
 										GTK_SHADOW_IN);
@@ -801,9 +818,9 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 
 	property_control =
 		ggv_postscript_view_get_property_control (control->priv->ps_view);
-
 	bonobo_object_add_interface (BONOBO_OBJECT (control),
 								 BONOBO_OBJECT (property_control));
+	bonobo_object_unref(BONOBO_OBJECT(property_control));
 
 	control->priv->uic =
 		bonobo_control_get_ui_component (BONOBO_CONTROL (control));
