@@ -152,15 +152,15 @@ set_file_items_sensitivity(GgvPostScriptView *ps_view, gboolean sens)
 	gchar *prop_val = sens?"1":"0";
 
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/commands/FileSaveMarked",
-                                     "sensitive", prop_val, NULL);
+								 "sensitive", prop_val, NULL);
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/commands/FilePrintMarked",
-                                     "sensitive", prop_val, NULL);
+								 "sensitive", prop_val, NULL);
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/commands/FilePrintAll",
-                                     "sensitive", prop_val, NULL);
+								 "sensitive", prop_val, NULL);
 }
 
 static void
-_set_page_item_sensitivity(GgvPostScriptView *ps_view, BonoboUIComponent *uic)
+_set_page_items_sensitivity(GgvPostScriptView *ps_view, BonoboUIComponent *uic)
 {
 	GtkGS *gs = GTK_GS(ps_view->priv->gs);
 	gchar *prop_val;
@@ -184,11 +184,11 @@ _set_page_item_sensitivity(GgvPostScriptView *ps_view, BonoboUIComponent *uic)
 }
 
 static void
-set_page_item_sensitivity(GgvPostScriptView *ps_view)
+set_page_items_sensitivity(GgvPostScriptView *ps_view)
 {
-	_set_page_item_sensitivity(ps_view, ps_view->priv->uic);
+	_set_page_items_sensitivity(ps_view, ps_view->priv->uic);
 	if(ps_view->priv->popup_uic != NULL)
-		_set_page_item_sensitivity(ps_view, ps_view->priv->popup_uic);
+		_set_page_items_sensitivity(ps_view, ps_view->priv->popup_uic);
 }
 
 static void
@@ -196,13 +196,15 @@ notify_page_count_change(GgvPostScriptView *ps_view)
 {
 	BonoboArg *arg;
 
-	set_page_item_sensitivity(ps_view);
+	set_page_items_sensitivity(ps_view);
+	set_file_items_sensitivity(ps_view, ggv_postscript_view_get_page_count(ps_view) > 0);
 
 	arg = bonobo_arg_new(TC_CORBA_long);
-	BONOBO_ARG_SET_LONG(arg, gtk_gs_get_page_count(GTK_GS(ps_view->priv->gs)));
+	BONOBO_ARG_SET_LONG(arg, ggv_postscript_view_get_page_count(ps_view));
 	bonobo_event_source_notify_listeners(ps_view->priv->property_bag->es,
 										 "Bonobo/Property:change:page_count",
 										 arg, NULL);
+
 	bonobo_arg_release(arg);
 }
 
@@ -224,7 +226,7 @@ notify_page_change(GgvPostScriptView *ps_view)
 {
 	BonoboArg *arg;
 
-	set_page_item_sensitivity(ps_view);
+	set_page_items_sensitivity(ps_view);
 	ggv_sidebar_page_changed(ps_view->priv->sidebar,
 							 gtk_gs_get_current_page(GTK_GS(ps_view->priv->gs)));
 
@@ -282,7 +284,7 @@ load_ps(GgvPostScriptView *ps_view, const gchar *fname)
 	ggv_postscript_view_goto_page(ps_view, 0);
 	notify_page_change(ps_view);
 	ggv_sidebar_update_coordinates(ps_view->priv->sidebar, 0.0, 0.0);
-	set_file_items_sensitivity(ps_view, ggv_postscript_view_get_current_page(ps_view) >= 0);
+	set_file_items_sensitivity(ps_view, ggv_postscript_view_get_page_count(ps_view) > 0);
 }
 
 /*
@@ -662,7 +664,7 @@ static gboolean
 save_file_sel_delete_event(GtkWidget *widget, GdkEventAny *e, gpointer data)
 {
 	gtk_widget_hide(widget);
-	return FALSE;
+	return TRUE;
 }
 
 static void
@@ -678,9 +680,10 @@ save_file_sel_ok_clicked(GtkWidget *widget, gpointer data)
 	doc = ggv_postscript_view_get_ps(ps_view, active_rows);
 	g_free(active_rows);
 
+	/* get file name */
+	gtk_widget_hide(ps_view->priv->save_file_sel);
+
 	if(doc != NULL) {
-		/* get file name */
-		gtk_widget_hide(ps_view->priv->save_file_sel);
 		fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(ps_view->priv->save_file_sel));
 
 		if(ggv_file_readable(fname)) {
@@ -991,8 +994,9 @@ ggv_postscript_view_create_ui(GgvPostScriptView *ps_view)
 									 listener_Toggle_cb, ps_view);
 	bonobo_ui_component_add_listener(ps_view->priv->uic, "OverrideOrientation",
 									 listener_Toggle_cb, ps_view);
-
-	set_page_item_sensitivity(ps_view);
+	set_file_items_sensitivity(ps_view,
+							   ggv_postscript_view_get_page_count(ps_view) > 0);
+	set_page_items_sensitivity(ps_view);
 	sync_orientation_items(ps_view);
 	sync_size_items(ps_view);
 }
@@ -1356,7 +1360,9 @@ ggv_postscript_view_get_object(BonoboItemContainer *item_container,
 
 	corba_object = bonobo_object_corba_objref (object);
 
-	return bonobo_object_dup_ref (corba_object, ev);
+	corba_object = bonobo_object_dup_ref(corba_object, ev);
+
+	return corba_object;
 }
 
 BonoboObject *
@@ -1372,7 +1378,9 @@ ggv_postscript_view_add_interfaces (GgvPostScriptView *ps_view,
 
 	/* Interface Bonobo::PersistStream */
 	stream = bonobo_persist_stream_new (load_ps_from_stream, 
-										NULL, NULL, NULL, ps_view);
+										NULL, NULL,
+										"OAFIID:GNOME_GGV_PostScriptView",
+										ps_view);
 	if (!stream) {
 		bonobo_object_unref (BONOBO_OBJECT (to_aggregate));
 		return NULL;
@@ -1552,26 +1560,22 @@ ggv_postscript_view_destroy(BonoboObject *object)
 		bonobo_object_unref(BONOBO_OBJECT(ps_view->priv->property_bag));
 		ps_view->priv->property_bag = NULL;
 	}
-
-	if(ps_view->priv->property_control) {
-		bonobo_object_unref(BONOBO_OBJECT(ps_view->priv->property_control));
-		ps_view->priv->property_control = NULL;
-	}
-
 	if(ps_view->priv->gs) {
-		gtk_widget_destroy(ps_view->priv->gs);
+		gtk_widget_unref(ps_view->priv->gs);
 		ps_view->priv->gs = NULL;
 	}
-
 	if(ps_view->priv->msg_win) {
 		ggv_msg_window_free(ps_view->priv->msg_win);
 		ps_view->priv->msg_win = NULL;
 	}
-
 	if(ps_view->priv->uic) {
 		bonobo_object_unref(BONOBO_OBJECT(ps_view->priv->uic));
 		ps_view->priv->uic = NULL;
 	}
+	if(ps_view->priv->sidebar) {
+		bonobo_object_unref(BONOBO_OBJECT(ps_view->priv->sidebar));
+		ps_view->priv->sidebar = NULL;
+	}
 
 	if (BONOBO_OBJECT_CLASS (ggv_postscript_view_parent_class)->destroy)
 		BONOBO_OBJECT_CLASS(ggv_postscript_view_parent_class)->destroy(object);
@@ -1881,8 +1885,6 @@ ggv_postscript_view_construct(GgvPostScriptView *ps_view,
 	/* UI Component */
 	ps_view->priv->uic = bonobo_ui_component_new("GgvPostScriptView");
 
-	ggv_postscript_view_add_interfaces (ps_view, BONOBO_OBJECT (ps_view));
-
 	ps_view->priv->sidebar = ggv_sidebar_new(ps_view);
 
 	return ps_view;
@@ -1918,5 +1920,5 @@ ggv_postscript_view_set_popup_ui_component(GgvPostScriptView *ps_view,
 										   BonoboUIComponent *uic)
 {
 	ps_view->priv->popup_uic = uic;
-	_set_page_item_sensitivity(ps_view, uic);
+	_set_page_items_sensitivity(ps_view, uic);
 }
