@@ -54,10 +54,6 @@ ggv_sidebar_destroy (BonoboObject *object)
 		gtk_widget_unref (sidebar->priv->root);
 		sidebar->priv->root = NULL;
 	}
-	if (sidebar->priv->ps_view) {
-		bonobo_object_unref(sidebar->priv->ps_view);
-		sidebar->priv->ps_view = NULL;
-	}
 
 	if(BONOBO_OBJECT_CLASS (ggv_sidebar_parent_class)->destroy)
 		BONOBO_OBJECT_CLASS (ggv_sidebar_parent_class)->destroy (object);
@@ -82,7 +78,7 @@ static void
 ggv_sidebar_class_init (GgvSidebarClass *klass)
 {
 	BonoboObjectClass *bonobo_object_class = (BonoboObjectClass *)klass;
-	GObjectClass *object_class = (BonoboControlClass *)klass;
+	GObjectClass *object_class = (GObjectClass *)klass;
 
 	ggv_sidebar_parent_class = gtk_type_class (bonobo_control_get_type ());
 
@@ -258,7 +254,6 @@ ggv_sidebar_construct (GgvSidebar *sidebar, GgvPostScriptView *ps_view)
 	g_return_val_if_fail (GGV_IS_SIDEBAR (sidebar), NULL);
 
 	sidebar->priv->ps_view = ps_view;
-	bonobo_object_ref (BONOBO_OBJECT (ps_view));
 
 	/* with a sidebar on the left */
 	sidebar->priv->root = gtk_vbox_new(FALSE, 0);
