@@ -24,11 +24,14 @@
 
 #include <ggv-control.h>
 #if 0
-#include <ggv-embeddable.h>
+#  include <ggv-embeddable.h>
 #endif /* 0 */
 
+#define BONOBO_DEBUG
+
 #ifdef BONOBO_DEBUG
-#define LOG_FILE_NAME "/tmp/ggv-postscript-viewer.log"
+#  include <signal.h>
+#  define LOG_FILE_NAME "/tmp/ggv-postscript-viewer.log"
 
 static FILE *log_file = NULL;
 static ggv_postscript_viewer_log_func(const gchar *log_domain,
@@ -41,6 +44,12 @@ static ggv_postscript_viewer_log_func(const gchar *log_domain,
 	fprintf(f, "%s [%d]: %s\n", log_domain?log_domain:"", log_level, message);
 	fflush(f);
 }
+
+void sigterm_handler(int signum)
+{
+	bonobo_main_quit();
+	bonobo_debug_shutdown();
+}
 #endif /* BONOBO_DEBUG */
 
 static BonoboObject *
@@ -68,6 +77,8 @@ ggv_postscript_viewer_factory (BonoboGenericFactory *this, const char *oaf_iid,
 							  log_file);
 		}
 	}
+
+	signal(SIGTERM, sigterm_handler);
 #endif /* BONOBO_DEBUG */
 
 	hadj = GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 1.0, 0.01, 0.1, 0.09));
@@ -96,5 +107,21 @@ ggv_postscript_viewer_factory (BonoboGenericFactory *this, const char *oaf_iid,
 	return retval;
 }
 
-BONOBO_ACTIVATION_FACTORY("OAFIID:GNOME_GGV_Factory", "ggv-postscript-viewer", 
-			  VERSION, ggv_postscript_viewer_factory, NULL);
+int
+main (int argc, char *argv [])					
+{									
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);                       
+	bind_textdomain_codeset (PACKAGE, "UTF-8");                     
+	textdomain (PACKAGE);                                           
+
+#if 0
+	/* compile this to enable attaching with gdb before the factory
+	   actually starts... */
+	sleep(15);
+#endif
+									
+	BONOBO_FACTORY_INIT ("ggv-postscript-viewer", VERSION, &argc, argv);		
+									
+	return bonobo_generic_factory_main ("OAFIID:GNOME_GGV_Factory",
+										ggv_postscript_viewer_factory, NULL);	
+}                                                                       
