@@ -83,7 +83,14 @@ ggv_prefs_dialog_apply(GgvPrefsDialog *dlg)
         ggv_panel = GTK_TOGGLE_BUTTON(dlg->sidebar)->active;
         ggv_save_geometry = GTK_TOGGLE_BUTTON(dlg->savegeo)->active;
 	ggv_toolbar = GTK_TOGGLE_BUTTON(dlg->toolbar)->active;
-        ggv_toolbar_labels = GTK_TOGGLE_BUTTON(dlg->tblabels)->active;
+        for(i = 0; i < GGV_TOOLBAR_STYLE_LAST; i++) {
+                if(GTK_TOGGLE_BUTTON(dlg->tbstyle[i])->active) {
+                        ggv_toolbar_style = (GgvToolbarStyle)i;
+                        break;
+                }
+        }
+        if(i == GGV_TOOLBAR_STYLE_LAST)
+                ggv_toolbar_style = GGV_TOOLBAR_STYLE_DEFAULT;
         ggv_menubar = GTK_TOGGLE_BUTTON(dlg->mbar)->active;
         ggv_statusbar = GTK_TOGGLE_BUTTON(dlg->sbar)->active;
         ggv_autojump = GTK_TOGGLE_BUTTON(dlg->auto_jump)->active;
@@ -219,8 +226,8 @@ ggv_prefs_dialog_setup(GgvPrefsDialog *dlg)
                                      ggv_menubar);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->toolbar),
                                      ggv_toolbar);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->tblabels),
-                                     ggv_toolbar_labels);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->tbstyle[ggv_toolbar_style]),
+                                     TRUE);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->sbar),
                                      ggv_statusbar);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->savegeo),
@@ -270,11 +277,19 @@ ggv_prefs_dialog_show(GgvPrefsDialog *dlg)
 GtkWidget *
 ggv_prefs_dialog_new()
 {
+        static const gchar *tbstyle_labels[] = {
+                N_("Use GNOME defaults"),
+                N_("Show both icons and text"),
+                N_("Show only icons"),
+                N_("Show only text")
+        };
+
         GgvPrefsDialog *dlg;
         GtkWidget *widget, *vbox, *sep, *bbox;
-        GtkWidget *table, *label, *menu;
+        GtkWidget *table, *label, *menu, *frame;
         gint i;
         GtkGSPaperSize *papersizes = gtk_gs_defaults_get_paper_sizes();
+        GSList *tbstyle_group = NULL;
 
         dlg = GGV_PREFS_DIALOG(g_object_new(GGV_TYPE_PREFS_DIALOG, NULL));
         widget = GTK_WIDGET(dlg);
@@ -568,17 +583,28 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->toolbar);
 
-        /* show toolbar labels */
-        dlg->tblabels = gtk_check_button_new_with_label(_("Show labels in toolbar"));
-        gtk_table_attach(GTK_TABLE(table), dlg->tblabels,
+        /* toolbar style */
+        frame = gtk_frame_new(_("Toolbar style"));
+        gtk_widget_show(frame);
+        vbox = gtk_vbox_new(TRUE, 0);
+        gtk_container_add(GTK_CONTAINER(frame), vbox);
+        gtk_widget_show(vbox);
+        gtk_table_attach(GTK_TABLE(table), frame,
                          0, 1, 4, 5,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-        g_signal_connect(G_OBJECT(dlg->tblabels), "clicked",
-                         G_CALLBACK(prefs_dlg_change_handler), dlg);
-        gtk_widget_show(dlg->tblabels);
-
+        for(i = 0; i < GGV_TOOLBAR_STYLE_LAST; i++) {
+                dlg->tbstyle[i] = gtk_radio_button_new_with_label(tbstyle_group,
+                                                                  _(tbstyle_labels[i]));
+                tbstyle_group = gtk_radio_button_group(GTK_RADIO_BUTTON(dlg->tbstyle[i]));
+                g_signal_connect(G_OBJECT(dlg->tbstyle[i]), "toggled",
+                                 G_CALLBACK(prefs_dlg_change_handler), dlg);
+                gtk_widget_show(dlg->tbstyle[i]);
+                gtk_box_pack_start(GTK_BOX(vbox), dlg->tbstyle[i], TRUE, TRUE,
+                                   GNOME_PAD_SMALL);
+        }
+                                   
         /* show statusbar */
         dlg->sbar = gtk_check_button_new_with_label(_("Show statusbar by default"));
         gtk_table_attach(GTK_TABLE(table), dlg->sbar,
