@@ -12,7 +12,6 @@
 #include <gnome.h>
 #include <bonobo-activation/bonobo-activation.h>
 #include <libgnomeui/gnome-window-icon.h>
-#include <gconf/gconf-client.h>
 #include <bonobo.h>
 #include <bonobo/bonobo-ui-main.h>
 
@@ -121,8 +120,41 @@ sync_settings_popup_items(GgvWindow *win)
 static void
 sync_toolbar_style(GgvWindow *win)
 {
-        bonobo_ui_component_set_prop(win->uic, "/Toolbar", "look",
-                                     ggv_toolbar_labels?"both":"icon", NULL);
+        const gchar *tbstyle;
+        gchar *gnome_tbstyle;
+
+        switch(ggv_toolbar_style) {
+        case GGV_TOOLBAR_STYLE_DEFAULT:
+                gnome_tbstyle = gconf_client_get_string(ggv_prefs_gconf_client(),
+                                                        "/desktop/gnome/interface/toolbar_style",
+                                                        NULL);
+                if(gnome_tbstyle) {
+                        if(!strcmp(gnome_tbstyle, "icons"))
+                                tbstyle = "icon";
+                        else if(!strcmp(gnome_tbstyle, "both"))
+                                tbstyle = "both";
+                        else if(!strcmp(gnome_tbstyle, "text"))
+                                tbstyle = "text";
+                        else
+                                tbstyle = "both";
+                        g_free(gnome_tbstyle);
+                }
+                else
+                        tbstyle = "both";
+                break;
+        case GGV_TOOLBAR_STYLE_BOTH:
+                tbstyle = "both";
+                break;
+        case GGV_TOOLBAR_STYLE_ICONS:
+                tbstyle = "icon";
+                break;
+        case GGV_TOOLBAR_STYLE_TEXT:
+                tbstyle = "text";
+                break;
+        }
+        if(tbstyle)
+                bonobo_ui_component_set_prop(win->uic, "/Toolbar", "look",
+                                             tbstyle, NULL);
 }
 
 static void
@@ -144,11 +176,11 @@ control_property_changed_handler(BonoboListener    *listener,
                                         BONOBO_ARG_GET_STRING(any));
         }
         else if(!g_strcasecmp(event_name, "Bonobo/Property:change:page")) {
-                if(win->current_page == BONOBO_ARG_GET_INT(any) &&
+                if(win->current_page == BONOBO_ARG_GET_LONG(any) &&
                    win->current_page < 0)
                         return;
 
-                win->current_page = BONOBO_ARG_GET_INT(any);
+                win->current_page = BONOBO_ARG_GET_LONG(any);
                 if(win->current_page < 0) {
                         GtkWidget *dlg;
                         dlg = gtk_message_dialog_new(GTK_WINDOW(win),
@@ -163,6 +195,11 @@ control_property_changed_handler(BonoboListener    *listener,
                 }
         }
         else if(!g_strcasecmp(event_name, "Bonobo/Property:change:page_count")) {
+                bonobo_ui_component_set_prop(win->uic,
+                                             "/commands/FileReload",
+                                             "sensitive",
+                                             (BONOBO_ARG_GET_LONG(any) > 0)?"1":"0",
+                                             NULL);
         }
 }
 
@@ -176,7 +213,7 @@ static gboolean
 file_sel_delete_event(GtkWidget *widget, GdkEventAny *e, gpointer data)
 {
         gtk_widget_hide(widget);
-        return FALSE;
+        return TRUE;
 }
 
 static void
@@ -224,7 +261,7 @@ verb_FileOpen(BonoboUIComponent *uic, gpointer data, const char *cname)
                 g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(win->file_sel)->cancel_button),
                                  "clicked", G_CALLBACK(file_sel_cancel_clicked), win);
                 g_signal_connect(G_OBJECT(win->file_sel), "delete_event",
-                                 G_CALLBACK(file_sel_cancel_clicked), win);
+                                 G_CALLBACK(file_sel_delete_event), win);
                 g_signal_connect(G_OBJECT(win->file_sel), "unmap",
                                  G_CALLBACK(file_sel_unmap), NULL);
         }
@@ -485,7 +522,22 @@ ggv_window_destroy(GtkObject *object)
                 bonobo_object_unref(BONOBO_OBJECT(win->ctlframe));
                 win->ctlframe = NULL;
         }
-
+        if(win->control != CORBA_OBJECT_NIL) {
+                bonobo_object_release_unref(win->control, NULL);
+                win->control = CORBA_OBJECT_NIL;
+        }
+        if(win->uic) {
+                bonobo_object_unref(win->uic);
+                win->uic = NULL;
+        }
+        if(win->popup_uic) {
+                bonobo_object_unref(win->popup_uic);
+                win->popup_uic = NULL;
+        }
+        if(win->pb) {
+                bonobo_object_release_unref(win->pb, NULL);
+                win->pb = CORBA_OBJECT_NIL;
+        }
         if(win->filename) {
                 g_free(win->filename);
                 win->filename = NULL;
@@ -502,7 +554,6 @@ static gboolean
 ggv_window_delete_event(GtkWidget *widget, GdkEventAny *e)
 {
         ggv_window_close(GGV_WINDOW(widget));
-
         return TRUE;
 }
 
@@ -624,7 +675,6 @@ ggv_window_new(void)
 
 	/* add menu and toolbar */
 	ui_container = bonobo_window_get_ui_container(BONOBO_WINDOW(win));
-	BONOBO_OBJREF(ui_container);
 	uic = bonobo_ui_component_new("ggv");
         win->uic = uic;
 	bonobo_ui_component_set_container(uic, BONOBO_OBJREF(ui_container),
@@ -672,6 +722,11 @@ ggv_window_new(void)
                         "Bonobo/Property:change:height,"
                         "Bonobo/Property:change:title,"
                         "Bonobo/Property:change:status";
+                bonobo_ui_component_set_prop(win->uic,
+                                             "/commands/FileReload",
+                                             "sensitive",
+                                             (bonobo_pbclient_get_long(pb, "page", NULL) >= 0)?"1":"0",
+                                             NULL);
                 bonobo_event_source_client_add_listener(pb,
                                                         (BonoboListenerCallbackFn)control_property_changed_handler,
                                                         mask, NULL, win);
@@ -701,11 +756,7 @@ ggv_window_new(void)
 	/* set default geometry */
         gtk_widget_set_usize(GTK_WIDGET(win),
                              ggv_default_width, ggv_default_height);
-#if 0
-	gtk_window_set_resizable(GTK_WINDOW(win), TRUE);
-#else
         gtk_window_set_policy(GTK_WINDOW(win), TRUE, TRUE, FALSE);
-#endif
 
 	return GTK_WIDGET(win);
 }
@@ -792,3 +843,9 @@ ggv_window_apply_prefs(GgvWindow *win)
                 }
         }
 }
+
+const GList *
+ggv_get_window_list()
+{
+        return window_list;
+}
