@@ -61,6 +61,7 @@ struct _GgvWindow
         gfloat xcoord, ycoord;
 
         gchar **uris_to_open;
+        gchar *filename;
 
         gint current_page;
 
@@ -83,6 +84,7 @@ GtkWidget *ggv_window_new               (void);
 void      ggv_window_close              (GgvWindow *win);
 gboolean  ggv_window_load               (GgvWindow *win, const gchar *filename);
 void      ggv_window_apply_prefs        (GgvWindow *win);
+const GList *ggv_get_window_list(void);
 
 G_END_DECLS
 
