@@ -272,3 +272,11 @@ ggv_raise_and_focus_widget (GtkWidget *widget)
 	gdk_window_show (widget->window);
 	gtk_widget_grab_focus (widget);
 }
+
+void
+ggv_get_window_size(GtkWidget *widget, gint *width, gint *height)
+{
+        *width = widget->allocation.width;
+        *height = widget->allocation.height;
+}
+
