@@ -1854,9 +1854,10 @@ gtk_gs_next_page(GtkGS *gs)
 	event.xclient.message_type  = gdk_x11_atom_to_xatom(gs_class->next_atom);
 	event.xclient.format        = 32;
         
-	_gdk_send_xevent(gdk_display,gs->message_window, FALSE, 0, &event); 
- 
-        gdk_flush();
+        gdk_error_trap_push ();
+        XSendEvent (gdk_display, gs->message_window, FALSE, 0, &event);
+        gdk_flush ();
+        gdk_error_trap_pop ();
 
 	return TRUE;
 }
@@ -1876,10 +1877,14 @@ gtk_gs_get_page_count(GtkGS *gs)
         if(!gs->gs_filename)
                 return 0;
 
-        if(gs->structured_doc && gs->doc)
-                return gs->doc->numpages;
+        if(gs->doc) {
+                if(gs->structured_doc)
+                        return gs->doc->numpages;
+                else
+                        return G_MAXINT;
+        }
         else
-                return G_MAXINT;
+                return 0;
 }
 
 gboolean
@@ -2554,16 +2559,35 @@ gtk_gs_get_postscript(GtkGS *gs, gint *pages)
         gchar *doc;
         gboolean free_pages = FALSE;
 
-        sink = gtk_gs_doc_sink_new();
-
         if(pages == NULL) {
-                int i, n = gtk_gs_get_page_count(gs);
-                pages = g_new0(gint, n);
-                for(i = 0; i < n; i++)
-                        pages[i] = TRUE;
-                free_pages = TRUE;
+                if(gs->doc->epsf) {
+                        FILE *f;
+                        struct stat sb;
+
+                        if(stat(GTK_GS_GET_PS_FILE(gs), &sb))
+                                return NULL;
+                        doc = g_new(gchar, sb.st_size);
+                        if(!doc)
+                                return NULL;
+                        f = fopen(GTK_GS_GET_PS_FILE(gs), "r");
+                        if(fread(doc, sb.st_size, 1, f) != 1) {
+                                g_free(doc);
+                                doc = NULL;
+                        }
+                        fclose(f);
+                        return doc;
+                }
+                else {
+                        int i, n = gtk_gs_get_page_count(gs);
+                        pages = g_new0(gint, n);
+                        for(i = 0; i < n; i++)
+                                pages[i] = TRUE;
+                        free_pages = TRUE;
+                }
         }
 
+        sink = gtk_gs_doc_sink_new();
+
         if(GTK_GS_IS_PDF(gs)) {
                 /* Save marked pages of the dsc file. The saved
                  * file is useless without the pdf file, but can
